from setuptools import setup, find_packages

setup(
    name='descaling',
    version='1.0.0',
    packages=find_packages(),
    url='',
    license='',
    author='lagmoellertim',
    author_email='mail@lagmoellertim.de',
    description='',
)
